@@ -11,7 +11,8 @@
 # under the License.
 
 
-import mock
+from unittest import mock
+
 from oslo_utils import uuidutils
 
 from kuryr.lib.binding.drivers import macvlan
